@@ -197,7 +197,7 @@ rdf_object_to_tbl <- function(rdfObject, timeSteps)
 
 rdf_trace_to_tbl <- function(rdfTrace, traceNum) 
 {
-  trace <- as.integer(rdfTrace$idx_sequential)
+  trace <- as.integer(rdfTrace$trace)
   timeSteps <- rdfTrace$times
   ruleSet <- rdfTrace$rule_set
   slotSet <- rdfTrace$slot_set # the input DMI on the input tab
@@ -213,7 +213,7 @@ rdf_trace_to_tbl <- function(rdfTrace, traceNum)
     lapply(rdfTrace$objects, rdf_object_to_tbl, timeSteps = timeSteps)
   ) %>%
     dplyr::mutate(
-      TraceNumber = traceNum, 
+      TraceNumber = trace, 
       RulesetFileName = ruleSet, 
       InputDMIName = slotSet
     ) %>%
